==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Part/App/FeaturePartSection.h <==
/***************************************************************************
 *   Copyright (c) 2007 Werner Mayer <wmayer[at]users.sourceforge.net>     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef PART_FEATUREPARTSECTION_H
#define PART_FEATUREPARTSECTION_H

#include <App/PropertyStandard.h>

#include "FeaturePartBoolean.h"


namespace Part
{

class Section : public Boolean
{
    PROPERTY_HEADER_WITH_OVERRIDE(Part::Section);

public:
    Section();

    App::PropertyBool Approximation;

    /** @name methods override Feature */
    //@{
    /// recalculate the Feature
    short mustExecute() const override;
protected:
    BRepAlgoAPI_BooleanOperation* makeOperation(const TopoDS_Shape&, const TopoDS_Shape&) const override;
    //@}
};

}

#endif // PART_FEATUREPARTSECTION_H

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Part/App/FeaturePartSection.h <==
/***************************************************************************
 *   Copyright (c) 2007 Werner Mayer <wmayer[at]users.sourceforge.net>     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef PART_FEATUREPARTSECTION_H
#define PART_FEATUREPARTSECTION_H

#include <App/PropertyStandard.h>

#include "FeaturePartBoolean.h"


namespace Part
{

class Section : public Boolean
{
    PROPERTY_HEADER_WITH_OVERRIDE(Part::Section);

public:
    Section();

    App::PropertyBool Approximation;

    /** @name methods override Feature */
    //@{
    /// recalculate the Feature
    short mustExecute() const override;

protected:
    BRepAlgoAPI_BooleanOperation* makeOperation(const TopoDS_Shape&,
                                                const TopoDS_Shape&) const override;
    const char *opCode() const override;
    //@}
};

}

#endif // PART_FEATUREPARTSECTION_H
